@@ -279,7 +279,9 @@ def withObjectCodeTemporaryAssignment(to_name, value_name, expression, emit, con
         getReleaseCode(value_name, emit, context)
 
 
-def pickCodeHelper(prefix, suffix, left_shape, right_shape, helpers, warn_missing=True):
+def pickCodeHelper(
+    prefix, suffix, left_shape, right_shape, helpers, nonhelpers, source_ref
+):
     left_part = left_shape.helper_code
     right_part = right_shape.helper_code
 
@@ -291,8 +293,8 @@ def pickCodeHelper(prefix, suffix, left_shape, right_shape, helpers, warn_missin
     if ideal_helper in helpers:
         return ideal_helper
 
-    if warn_missing:
-        onMissingHelper(ideal_helper)
+    if source_ref is not None and ideal_helper not in nonhelpers:
+        onMissingHelper(ideal_helper, source_ref)
 
     fallback_helper = "%s_%s_%s%s" % (prefix, "OBJECT", "OBJECT", suffix)
 
