@@ -48,6 +48,7 @@ from nuitka.Version import getNuitkaVersion
 
 from .BlobCodes import StreamData
 from .Emission import SourceCodeCollector
+from .ErrorCodes import getReleaseCode
 from .Indentation import indented
 from .templates.CodeTemplatesConstants import template_constants_reading
 
@@ -973,9 +974,6 @@ def getConstantAccess(to_name, constant, emit, context):
 
     emit("%s = %s;" % (value_name, code))
 
-    if ref_count:
-        context.addCleanupTempName(value_name)
-
     if to_name is not value_name:
         to_name.getCType().emitAssignConversionCode(
             to_name=to_name,
@@ -985,6 +983,13 @@ def getConstantAccess(to_name, constant, emit, context):
             context=context,
         )
 
+        # Above is supposed to transfer ownership.
+        if ref_count:
+            getReleaseCode(value_name, emit, context)
+    else:
+        if ref_count:
+            context.addCleanupTempName(value_name)
+
 
 def getModuleConstantCode(constant):
     assert type(constant) is str
@@ -1115,7 +1120,7 @@ def getConstantsDefinitionCode(context):
                 sys.base_exec_prefix  # @UndefinedVariable
             )
 
-    major, minor, micro = getNuitkaVersion().split(".")
+    major, minor, micro = getNuitkaVersion().split(".")[:3]
 
     if "rc" in micro:
         micro = micro[: micro.find("rc")]
