@@ -1,4 +1,4 @@
-#     Copyright 2018, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2019, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Part of "Nuitka", an optimizing Python compiler that is compatible and
 #     integrates with CPython, but also works on its own.
@@ -42,7 +42,7 @@ static PyObject *%(function_identifier)s_context( struct Nuitka_GeneratorObject
     // Local variable initialization
 %(function_var_inits)s
 
-    // Actual function code.
+    // Actual generator function body.
 %(function_body)s
 
 %(generator_exit)s
@@ -105,6 +105,6 @@ template_generator_return_exit = """\
 """
 
 
+from . import TemplateDebugWrapper  # isort:skip
 
-from . import TemplateDebugWrapper # isort:skip
 TemplateDebugWrapper.checkDebug(globals())
