@@ -1,4 +1,4 @@
-#     Copyright 2018, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2019, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Part of "Nuitka", an optimizing Python compiler that is compatible and
 #     integrates with CPython, but also works on its own.
@@ -40,9 +40,7 @@ class ExpressionBuiltinRangeBase(ExpressionChildrenHavingBase):
 
     def __init__(self, values, source_ref):
         ExpressionChildrenHavingBase.__init__(
-            self,
-            values     = values,
-            source_ref = source_ref
+            self, values=values, source_ref=source_ref
         )
 
     def getTypeShape(self):
@@ -64,9 +62,11 @@ class ExpressionBuiltinRangeBase(ExpressionChildrenHavingBase):
             if child.getIntegerValue() is None:
                 return True
 
-            if python_version >= 270 and \
-               child.isExpressionConstantRef() and \
-               type(child.getConstant()) is float:
+            if (
+                python_version >= 270
+                and child.isExpressionConstantRef()
+                and type(child.getConstant()) is float
+            ):
                 return True
 
         return False
@@ -80,12 +80,14 @@ class ExpressionBuiltinRangeBase(ExpressionChildrenHavingBase):
             if child.getIntegerValue() is None:
                 return True
 
-            if python_version >= 270 and \
-               child.isExpressionConstantRef() and \
-               type(child.getConstant()) is float:
+            if (
+                python_version >= 270
+                and child.isExpressionConstantRef()
+                and type(child.getConstant()) is float
+            ):
                 return True
 
-        step = self.getStep() # false alarm, pylint: disable=assignment-from-none
+        step = self.getStep()
 
         # A step of 0 will raise.
         if step is not None and step.getIntegerValue() == 0:
@@ -104,13 +106,10 @@ class ExpressionBuiltinRangeBase(ExpressionChildrenHavingBase):
             return self, None, None
 
         return trace_collection.getCompileTimeComputationResult(
-            node        = self,
-            computation = lambda : self.builtin_spec.simulateCall(
-                given_values
-            ),
-            description = "Built-in call to '%s' computed." % (
-                self.builtin_spec.getName()
-            )
+            node=self,
+            computation=lambda: self.builtin_spec.simulateCall(given_values),
+            description="Built-in call to '%s' computed."
+            % (self.builtin_spec.getName()),
         )
 
     def computeExpressionIter1(self, iter_node, trace_collection):
@@ -120,18 +119,19 @@ class ExpressionBuiltinRangeBase(ExpressionChildrenHavingBase):
 
         if iteration_length is not None and iteration_length > 256:
             result = makeExpressionBuiltinXrange(
-                low        = self.getLow(),
-                high       = self.getHigh(),
-                step       = self.getStep(),
-                source_ref = self.getSourceReference()
+                low=self.getLow(),
+                high=self.getHigh(),
+                step=self.getStep(),
+                source_ref=self.getSourceReference(),
             )
 
-            self.replaceWith(result)
+            self.parent.replaceChild(self, result)
+            del self.parent
 
             return (
                 iter_node,
                 "new_expression",
-                "Replaced 'range' with 'xrange' built-in call."
+                "Replaced 'range' with 'xrange' built-in call for iteration.",
             )
 
         # No exception will be raised on ranges.
@@ -157,19 +157,13 @@ class ExpressionBuiltinRangeBase(ExpressionChildrenHavingBase):
 class ExpressionBuiltinRange1(ExpressionBuiltinRangeBase):
     kind = "EXPRESSION_BUILTIN_RANGE1"
 
-    named_children = (
-        "low",
-    )
+    named_children = ("low",)
 
     def __init__(self, low, source_ref):
         assert low is not None
 
         ExpressionBuiltinRangeBase.__init__(
-            self,
-            values     = {
-                "low" : low,
-            },
-            source_ref = source_ref
+            self, values={"low": low}, source_ref=source_ref
         )
 
     getLow = ExpressionChildrenHavingBase.childGetter("low")
@@ -177,13 +171,10 @@ class ExpressionBuiltinRange1(ExpressionBuiltinRangeBase):
     def computeExpression(self, trace_collection):
         assert python_version < 300
 
-        low  = self.getLow()
+        low = self.getLow()
 
         return self.computeBuiltinSpec(
-            trace_collection = trace_collection,
-            given_values     = (
-                low,
-            )
+            trace_collection=trace_collection, given_values=(low,)
         )
 
     def getIterationLength(self):
@@ -205,10 +196,7 @@ class ExpressionBuiltinRange1(ExpressionBuiltinRangeBase):
 
         # TODO: Make sure to cast element_index to what CPython will give, for
         # now a downcast will do.
-        return makeConstantReplacementNode(
-            constant = int(element_index),
-            node     = self
-        )
+        return makeConstantReplacementNode(constant=int(element_index), node=self)
 
     def isKnownToBeIterable(self, count):
         return count is None or count == self.getIterationLength()
@@ -221,15 +209,10 @@ class ExpressionBuiltinRange2(ExpressionBuiltinRangeBase):
 
     def __init__(self, low, high, source_ref):
         ExpressionBuiltinRangeBase.__init__(
-            self,
-            values     = {
-                "low"  : low,
-                "high" : high
-            },
-            source_ref = source_ref
+            self, values={"low": low, "high": high}, source_ref=source_ref
         )
 
-    getLow  = ExpressionChildrenHavingBase.childGetter("low")
+    getLow = ExpressionChildrenHavingBase.childGetter("low")
     getHigh = ExpressionChildrenHavingBase.childGetter("high")
 
     builtin_spec = BuiltinParameterSpecs.builtin_range_spec
@@ -237,19 +220,15 @@ class ExpressionBuiltinRange2(ExpressionBuiltinRangeBase):
     def computeExpression(self, trace_collection):
         assert python_version < 300
 
-        low  = self.getLow()
+        low = self.getLow()
         high = self.getHigh()
 
         return self.computeBuiltinSpec(
-            trace_collection = trace_collection,
-            given_values     = (
-                low,
-                high
-            )
+            trace_collection=trace_collection, given_values=(low, high)
         )
 
     def getIterationLength(self):
-        low  = self.getLow()
+        low = self.getLow()
         high = self.getHigh()
 
         low = low.getIntegerValue()
@@ -265,7 +244,7 @@ class ExpressionBuiltinRange2(ExpressionBuiltinRangeBase):
         return max(0, high - low)
 
     def getIterationValue(self, element_index):
-        low  = self.getLow()
+        low = self.getLow()
         high = self.getHigh()
 
         low = low.getIntegerValue()
@@ -283,10 +262,7 @@ class ExpressionBuiltinRange2(ExpressionBuiltinRangeBase):
         if result >= high:
             return None
         else:
-            return makeConstantReplacementNode(
-                constant = result,
-                node     = self
-            )
+            return makeConstantReplacementNode(constant=result, node=self)
 
     def isKnownToBeIterable(self, count):
         return count is None or count == self.getIterationLength()
@@ -295,24 +271,14 @@ class ExpressionBuiltinRange2(ExpressionBuiltinRangeBase):
 class ExpressionBuiltinRange3(ExpressionBuiltinRangeBase):
     kind = "EXPRESSION_BUILTIN_RANGE3"
 
-    named_children = (
-        "low",
-        "high",
-        "step"
-    )
+    named_children = ("low", "high", "step")
 
     def __init__(self, low, high, step, source_ref):
         ExpressionBuiltinRangeBase.__init__(
-            self,
-            values     = {
-                "low"  : low,
-                "high" : high,
-                "step" : step
-            },
-            source_ref = source_ref
+            self, values={"low": low, "high": high, "step": step}, source_ref=source_ref
         )
 
-    getLow  = ExpressionChildrenHavingBase.childGetter("low")
+    getLow = ExpressionChildrenHavingBase.childGetter("low")
     getHigh = ExpressionChildrenHavingBase.childGetter("high")
     getStep = ExpressionChildrenHavingBase.childGetter("step")
 
@@ -321,21 +287,16 @@ class ExpressionBuiltinRange3(ExpressionBuiltinRangeBase):
     def computeExpression(self, trace_collection):
         assert python_version < 300
 
-        low  = self.getLow()
+        low = self.getLow()
         high = self.getHigh()
         step = self.getStep()
 
         return self.computeBuiltinSpec(
-            trace_collection = trace_collection,
-            given_values     = (
-                low,
-                high,
-                step
-            )
+            trace_collection=trace_collection, given_values=(low, high, step)
         )
 
     def getIterationLength(self):
-        low  = self.getLow()
+        low = self.getLow()
         high = self.getHigh()
         step = self.getStep()
 
@@ -379,7 +340,7 @@ class ExpressionBuiltinRange3(ExpressionBuiltinRangeBase):
         return self.getIterationLength() is not None
 
     def getIterationValue(self, element_index):
-        low  = self.getLow().getIntegerValue()
+        low = self.getLow().getIntegerValue()
 
         if low is None:
             return None
@@ -396,10 +357,7 @@ class ExpressionBuiltinRange3(ExpressionBuiltinRangeBase):
         if result >= high:
             return None
         else:
-            return makeConstantReplacementNode(
-                constant = result,
-                node     = self
-            )
+            return makeConstantReplacementNode(constant=result, node=self)
 
     def isKnownToBeIterable(self, count):
         return count is None or count == self.getIterationLength()
@@ -412,9 +370,7 @@ class ExpressionBuiltinXrangeBase(ExpressionChildrenHavingBase):
 
     def __init__(self, values, source_ref):
         ExpressionChildrenHavingBase.__init__(
-            self,
-            values     = values,
-            source_ref = source_ref
+            self, values=values, source_ref=source_ref
         )
 
     def getTypeShape(self):
@@ -450,7 +406,7 @@ class ExpressionBuiltinXrangeBase(ExpressionChildrenHavingBase):
             if child.getIntegerValue() is None:
                 return True
 
-        step = self.getStep() # false alarm, pylint: disable=assignment-from-none
+        step = self.getStep()
 
         # A step of 0 will raise.
         if step is not None and step.getIntegerValue() == 0:
@@ -469,13 +425,10 @@ class ExpressionBuiltinXrangeBase(ExpressionChildrenHavingBase):
             return self, None, None
 
         return trace_collection.getCompileTimeComputationResult(
-            node        = self,
-            computation = lambda : self.builtin_spec.simulateCall(
-                given_values
-            ),
-            description = "Built-in call to '%s' computed." % (
-                self.builtin_spec.getName()
-            )
+            node=self,
+            computation=lambda: self.builtin_spec.simulateCall(given_values),
+            description="Built-in call to '%s' computed."
+            % (self.builtin_spec.getName()),
         )
 
     def computeExpressionIter1(self, iter_node, trace_collection):
@@ -499,27 +452,18 @@ class ExpressionBuiltinXrangeBase(ExpressionChildrenHavingBase):
 class ExpressionBuiltinXrange1(ExpressionBuiltinXrangeBase):
     kind = "EXPRESSION_BUILTIN_XRANGE1"
 
-    named_children = (
-        "low",
-    )
+    named_children = ("low",)
 
     def __init__(self, low, source_ref):
         ExpressionBuiltinXrangeBase.__init__(
-            self,
-            values     = {
-                "low" : low,
-            },
-            source_ref = source_ref
+            self, values={"low": low}, source_ref=source_ref
         )
 
     def computeExpression(self, trace_collection):
         low = self.getLow()
 
         return self.computeBuiltinSpec(
-            trace_collection = trace_collection,
-            given_values     = (
-                low,
-            )
+            trace_collection=trace_collection, given_values=(low,)
         )
 
     getLow = ExpressionChildrenHavingBase.childGetter("low")
@@ -543,44 +487,29 @@ class ExpressionBuiltinXrange1(ExpressionBuiltinXrangeBase):
 
         # TODO: Make sure to cast element_index to what CPython will give, for
         # now a downcast will do.
-        return makeConstantReplacementNode(
-            constant = int(element_index),
-            node     = self
-        )
+        return makeConstantReplacementNode(constant=int(element_index), node=self)
 
 
 class ExpressionBuiltinXrange2(ExpressionBuiltinXrangeBase):
     kind = "EXPRESSION_BUILTIN_XRANGE2"
 
-    named_children = (
-        "low",
-        "high",
-    )
+    named_children = ("low", "high")
 
     def __init__(self, low, high, source_ref):
         ExpressionBuiltinXrangeBase.__init__(
-            self,
-            values     = {
-                "low"  : low,
-                "high" : high,
-            },
-            source_ref = source_ref
+            self, values={"low": low, "high": high}, source_ref=source_ref
         )
 
     def computeExpression(self, trace_collection):
-        low  = self.getLow()
+        low = self.getLow()
         high = self.getHigh()
 
         return self.computeBuiltinSpec(
-            trace_collection = trace_collection,
-            given_values     = (
-                low,
-                high
-            )
+            trace_collection=trace_collection, given_values=(low, high)
         )
 
     def getIterationLength(self):
-        low  = self.getLow()
+        low = self.getLow()
         high = self.getHigh()
 
         low = low.getIntegerValue()
@@ -596,7 +525,7 @@ class ExpressionBuiltinXrange2(ExpressionBuiltinXrangeBase):
         return max(0, high - low)
 
     def getIterationValue(self, element_index):
-        low  = self.getLow()
+        low = self.getLow()
         high = self.getHigh()
 
         low = low.getIntegerValue()
@@ -614,55 +543,37 @@ class ExpressionBuiltinXrange2(ExpressionBuiltinXrangeBase):
         if result >= high:
             return None
         else:
-            return makeConstantReplacementNode(
-                constant = result,
-                node     = self
-            )
+            return makeConstantReplacementNode(constant=result, node=self)
 
-    getLow  = ExpressionChildrenHavingBase.childGetter("low")
+    getLow = ExpressionChildrenHavingBase.childGetter("low")
     getHigh = ExpressionChildrenHavingBase.childGetter("high")
 
 
 class ExpressionBuiltinXrange3(ExpressionBuiltinXrangeBase):
     kind = "EXPRESSION_BUILTIN_XRANGE3"
 
-    named_children = (
-        "low",
-        "high",
-        "step"
-    )
+    named_children = ("low", "high", "step")
 
     def __init__(self, low, high, step, source_ref):
         ExpressionBuiltinXrangeBase.__init__(
-            self,
-            values     = {
-                "low"  : low,
-                "high" : high,
-                "step" : step
-            },
-            source_ref = source_ref
+            self, values={"low": low, "high": high, "step": step}, source_ref=source_ref
         )
 
     def computeExpression(self, trace_collection):
-        low  = self.getLow()
+        low = self.getLow()
         high = self.getHigh()
         step = self.getStep()
 
         return self.computeBuiltinSpec(
-            trace_collection = trace_collection,
-            given_values     = (
-                low,
-                high,
-                step
-            )
+            trace_collection=trace_collection, given_values=(low, high, step)
         )
 
-    getLow  = ExpressionChildrenHavingBase.childGetter("low")
+    getLow = ExpressionChildrenHavingBase.childGetter("low")
     getHigh = ExpressionChildrenHavingBase.childGetter("high")
     getStep = ExpressionChildrenHavingBase.childGetter("step")
 
     def getIterationLength(self):
-        low  = self.getLow()
+        low = self.getLow()
         high = self.getHigh()
         step = self.getStep()
 
@@ -703,7 +614,7 @@ class ExpressionBuiltinXrange3(ExpressionBuiltinXrangeBase):
         return int(estimate)
 
     def getIterationValue(self, element_index):
-        low  = self.getLow().getIntegerValue()
+        low = self.getLow().getIntegerValue()
 
         if low is None:
             return None
@@ -720,28 +631,15 @@ class ExpressionBuiltinXrange3(ExpressionBuiltinXrangeBase):
         if result >= high:
             return None
         else:
-            return makeConstantReplacementNode(
-                constant = result,
-                node     = self
-            )
+            return makeConstantReplacementNode(constant=result, node=self)
 
 
 def makeExpressionBuiltinXrange(low, high, step, source_ref):
     if high is None:
-        return ExpressionBuiltinXrange1(
-            low        = low,
-            source_ref = source_ref
-        )
+        return ExpressionBuiltinXrange1(low=low, source_ref=source_ref)
     elif step is None:
-        return ExpressionBuiltinXrange2(
-            low        = low,
-            high       = high,
-            source_ref = source_ref
-        )
+        return ExpressionBuiltinXrange2(low=low, high=high, source_ref=source_ref)
     else:
         return ExpressionBuiltinXrange3(
-            low        = low,
-            high       = high,
-            step       = step,
-            source_ref = source_ref
+            low=low, high=high, step=step, source_ref=source_ref
         )
