@@ -1,4 +1,4 @@
-#     Copyright 2018, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2019, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Part of "Nuitka", an optimizing Python compiler that is compatible and
 #     integrates with CPython, but also works on its own.
@@ -37,14 +37,12 @@ from nuitka.PythonVersions import python_version
 def makeConstantReplacementNode(constant, node):
     from .ConstantRefNodes import makeConstantRefNode
 
-    return makeConstantRefNode(
-        constant   = constant,
-        source_ref = node.getSourceReference()
-    )
+    return makeConstantRefNode(constant=constant, source_ref=node.getSourceReference())
 
 
-def makeRaiseExceptionReplacementExpression(expression, exception_type,
-                                            exception_value):
+def makeRaiseExceptionReplacementExpression(
+    expression, exception_type, exception_value
+):
     from .ExceptionNodes import ExpressionRaiseException
     from .BuiltinRefNodes import ExpressionBuiltinExceptionRef
 
@@ -57,26 +55,23 @@ def makeRaiseExceptionReplacementExpression(expression, exception_type,
             '%s: Will always raise exception: "%s(%s)"',
             source_ref.getAsString(),
             exception_type,
-            exception_value
+            exception_value,
         )
 
     result = ExpressionRaiseException(
-        exception_type  = ExpressionBuiltinExceptionRef(
-            exception_name = exception_type,
-            source_ref     = source_ref
+        exception_type=ExpressionBuiltinExceptionRef(
+            exception_name=exception_type, source_ref=source_ref
         ),
-        exception_value = makeConstantReplacementNode(
-            constant = exception_value,
-            node     = expression
+        exception_value=makeConstantReplacementNode(
+            constant=exception_value, node=expression
         ),
-        source_ref      = source_ref
+        source_ref=source_ref,
     )
 
     return result
 
 
-def makeRaiseExceptionReplacementStatement(statement, exception_type,
-                                           exception_value):
+def makeRaiseExceptionReplacementStatement(statement, exception_type, exception_value):
     from .ExceptionNodes import StatementRaiseExceptionImplicit
     from .BuiltinRefNodes import ExpressionBuiltinExceptionRef
 
@@ -89,21 +84,19 @@ def makeRaiseExceptionReplacementStatement(statement, exception_type,
             '%s: Will always raise exception: "%s(%s)"',
             source_ref.getAsString(),
             exception_type,
-            exception_value
+            exception_value,
         )
 
     result = StatementRaiseExceptionImplicit(
-        exception_type  = ExpressionBuiltinExceptionRef(
-            exception_name = exception_type,
-            source_ref     = source_ref
+        exception_type=ExpressionBuiltinExceptionRef(
+            exception_name=exception_type, source_ref=source_ref
         ),
-        exception_value = makeConstantReplacementNode(
-            constant = exception_value,
-            node     = statement
+        exception_value=makeConstantReplacementNode(
+            constant=exception_value, node=statement
         ),
-        exception_cause = None,
-        exception_trace = None,
-        source_ref      = source_ref
+        exception_cause=None,
+        exception_trace=None,
+        source_ref=source_ref,
     )
 
     return result
@@ -120,14 +113,15 @@ def makeRaiseExceptionReplacementExpressionFromInstance(expression, exception):
         value = args
 
     return makeRaiseExceptionReplacementExpression(
-        expression      = expression,
-        exception_type  = exception.__class__.__name__,
-        exception_value = value
+        expression=expression,
+        exception_type=exception.__class__.__name__,
+        exception_value=value,
     )
 
 
-def makeRaiseExceptionExpressionFromTemplate(exception_type, template,
-                                             template_args, source_ref):
+def makeRaiseExceptionExpressionFromTemplate(
+    exception_type, template, template_args, source_ref
+):
     from .ExceptionNodes import ExpressionRaiseException
     from .BuiltinRefNodes import ExpressionBuiltinExceptionRef
     from .OperatorNodes import makeBinaryOperationNode
@@ -136,47 +130,39 @@ def makeRaiseExceptionExpressionFromTemplate(exception_type, template,
 
     if type(template_args) is tuple:
         template_args = ExpressionMakeTuple(
-            elements   = template_args,
-            source_ref = source_ref
+            elements=template_args, source_ref=source_ref
         )
 
     return ExpressionRaiseException(
-        exception_type  = ExpressionBuiltinExceptionRef(
-            exception_name = exception_type,
-            source_ref     = source_ref
+        exception_type=ExpressionBuiltinExceptionRef(
+            exception_name=exception_type, source_ref=source_ref
         ),
-        exception_value = makeBinaryOperationNode(
-            operator   = "Mod",
-            left       =  makeConstantRefNode(
-                constant      = template,
-                source_ref    = source_ref,
-                user_provided = True
+        exception_value=makeBinaryOperationNode(
+            operator="Mod",
+            left=makeConstantRefNode(
+                constant=template, source_ref=source_ref, user_provided=True
             ),
-            right      = template_args,
-            source_ref = source_ref
+            right=template_args,
+            source_ref=source_ref,
         ),
-        source_ref      = source_ref
+        source_ref=source_ref,
     )
 
 
-def makeRaiseTypeErrorExceptionReplacementFromTemplateAndValue(template,
-                                                               operation,
-                                                               original_node,
-                                                               value_node):
+def makeRaiseTypeErrorExceptionReplacementFromTemplateAndValue(
+    template, operation, original_node, value_node
+):
     shape = value_node.getTypeShape()
 
     type_name = shape.getTypeName()
 
     if type_name is not None:
         result = makeRaiseExceptionReplacementExpressionFromInstance(
-            expression = original_node,
-            exception  = TypeError(template % type_name if '%' in template else template)
+            expression=original_node,
+            exception=TypeError(template % type_name if "%" in template else template),
         )
 
-        result = wrapExpressionWithNodeSideEffects(
-            new_node = result,
-            old_node = value_node
-        )
+        result = wrapExpressionWithNodeSideEffects(new_node=result, old_node=value_node)
 
     else:
         from .AttributeNodes import ExpressionAttributeLookup
@@ -185,42 +171,38 @@ def makeRaiseTypeErrorExceptionReplacementFromTemplateAndValue(template,
         source_ref = original_node.getSourceReference()
 
         result = makeRaiseExceptionExpressionFromTemplate(
-            exception_type = "TypeError",
-            template       = "object of type '%s' has no len()",
-            template_args  = ExpressionAttributeLookup(
-                source         = ExpressionBuiltinType1(
-                    value      = value_node.makeClone(),
-                    source_ref = source_ref
+            exception_type="TypeError",
+            template="object of type '%s' has no len()",
+            template_args=ExpressionAttributeLookup(
+                source=ExpressionBuiltinType1(
+                    value=value_node.makeClone(), source_ref=source_ref
                 ),
-                attribute_name = "__name__",
-                source_ref     = source_ref
+                attribute_name="__name__",
+                source_ref=source_ref,
             ),
-            source_ref     = source_ref
+            source_ref=source_ref,
         )
 
         type_name = shape.__name__
 
-    return result, "new_raise", "Raising for use of '%s' on %s '%s'." % (
-        operation,
-        "type" if type_name is not None else "shape",
-        type_name
+    return (
+        result,
+        "new_raise",
+        "Raising for use of '%s' on %s '%s'."
+        % (operation, "type" if type_name is not None else "shape", type_name),
     )
 
 
 def makeCompileTimeConstantReplacementNode(value, node):
     # This needs to match code in isCompileTimeConstantValue
     if isConstant(value):
-        return makeConstantReplacementNode(
-            constant = value,
-            node     = node
-        )
+        return makeConstantReplacementNode(constant=value, node=node)
     elif type(value) is type:
         if value.__name__ in builtin_names:
             from .BuiltinRefNodes import makeExpressionBuiltinRef
 
             return makeExpressionBuiltinRef(
-                builtin_name = value.__name__,
-                source_ref   = node.getSourceReference()
+                builtin_name=value.__name__, source_ref=node.getSourceReference()
             )
         else:
             return node
@@ -239,17 +221,13 @@ def getComputationResult(node, computation, description):
         result = computation()
     except Exception as e:
         new_node = makeRaiseExceptionReplacementExpressionFromInstance(
-            expression = node,
-            exception  = e
+            expression=node, exception=e
         )
 
         change_tags = "new_raise"
         change_desc = description + " Predicted to raise an exception."
     else:
-        new_node = makeCompileTimeConstantReplacementNode(
-            value = result,
-            node  = node
-        )
+        new_node = makeCompileTimeConstantReplacementNode(value=result, node=node)
 
         if isDebug():
             assert new_node is not node, (node, result)
@@ -268,12 +246,11 @@ def makeStatementExpressionOnlyReplacementNode(expression, node):
     from .StatementNodes import StatementExpressionOnly
 
     return StatementExpressionOnly(
-        expression = expression,
-        source_ref = node.getSourceReference()
+        expression=expression, source_ref=node.getSourceReference()
     )
 
 
-def mergeStatements(statements, allow_none = False):
+def mergeStatements(statements, allow_none=False):
     """ Helper function that merges nested statement sequences. """
     merged_statements = []
 
@@ -296,8 +273,7 @@ def makeStatementsSequenceReplacementNode(statements, node):
     from .StatementNodes import StatementsSequence
 
     return StatementsSequence(
-        statements = mergeStatements(statements),
-        source_ref = node.getSourceReference()
+        statements=mergeStatements(statements), source_ref=node.getSourceReference()
     )
 
 
@@ -319,30 +295,29 @@ def wrapExpressionWithSideEffects(side_effects, old_node, new_node):
         side_effects = sum(
             (
                 side_effect.extractSideEffects()
-                for side_effect in
-                side_effects
+                for side_effect in side_effects
                 if side_effect.mayHaveSideEffects()
             ),
-            ()
+            (),
         )
 
         if side_effects:
             new_node = ExpressionSideEffects(
-                expression   = new_node,
-                side_effects = side_effects,
-                source_ref   = old_node.getSourceReference()
+                expression=new_node,
+                side_effects=side_effects,
+                source_ref=old_node.getSourceReference(),
             )
 
     return new_node
 
+
 def wrapExpressionWithNodeSideEffects(new_node, old_node):
     return wrapExpressionWithSideEffects(
-        side_effects = old_node.extractSideEffects(),
-        old_node     = old_node,
-        new_node     = new_node
+        side_effects=old_node.extractSideEffects(), old_node=old_node, new_node=new_node
     )
 
-def wrapStatementWithSideEffects(new_node, old_node, allow_none = False):
+
+def wrapStatementWithSideEffects(new_node, old_node, allow_none=False):
     assert new_node is not None or allow_none
 
     side_effects = old_node.extractSideEffects()
@@ -352,32 +327,29 @@ def wrapStatementWithSideEffects(new_node, old_node, allow_none = False):
 
         side_effects = tuple(
             StatementExpressionOnly(
-                expression = side_effect,
-                source_ref = side_effect.getSourceReference()
+                expression=side_effect, source_ref=side_effect.getSourceReference()
             )
             for side_effect in side_effects
         )
 
         if new_node is not None:
             new_node = makeStatementsSequenceReplacementNode(
-                statements = side_effects + (new_node,),
-                node       = old_node
+                statements=side_effects + (new_node,), node=old_node
             )
         else:
             new_node = makeStatementsSequenceReplacementNode(
-                statements = side_effects,
-                node       = old_node
+                statements=side_effects, node=old_node
             )
 
     return new_node
 
+
 def makeStatementOnlyNodesFromExpressions(expressions):
     from .StatementNodes import StatementExpressionOnly, StatementsSequence
 
     statements = tuple(
         StatementExpressionOnly(
-            expression = expression,
-            source_ref = expression.getSourceReference()
+            expression=expression, source_ref=expression.getSourceReference()
         )
         for expression in expressions
     )
@@ -388,8 +360,7 @@ def makeStatementOnlyNodesFromExpressions(expressions):
         return statements[0]
     else:
         return StatementsSequence(
-            statements = statements,
-            source_ref = statements[0].getSourceReference()
+            statements=statements, source_ref=statements[0].getSourceReference()
         )
 
 
@@ -397,17 +368,11 @@ def makeVariableRefNode(variable, source_ref):
     if variable.isTempVariable():
         from .VariableRefNodes import ExpressionTempVariableRef
 
-        return ExpressionTempVariableRef(
-            variable   = variable,
-            source_ref = source_ref
-        )
+        return ExpressionTempVariableRef(variable=variable, source_ref=source_ref)
     else:
         from .VariableRefNodes import ExpressionVariableRef
 
-        return ExpressionVariableRef(
-            variable   = variable,
-            source_ref = source_ref
-        )
+        return ExpressionVariableRef(variable=variable, source_ref=source_ref)
 
 
 def makeExpressionBuiltinLocals(provider, source_ref):
@@ -417,27 +382,23 @@ def makeExpressionBuiltinLocals(provider, source_ref):
     if provider.isCompiledPythonModule():
         from .GlobalsLocalsNodes import ExpressionBuiltinGlobals
 
-        return ExpressionBuiltinGlobals(
-            source_ref = source_ref
-        )
+        return ExpressionBuiltinGlobals(source_ref=source_ref)
     else:
         from .GlobalsLocalsNodes import (
             ExpressionBuiltinLocalsCopy,
             ExpressionBuiltinLocalsRef,
-            ExpressionBuiltinLocalsUpdated
+            ExpressionBuiltinLocalsUpdated,
         )
 
         if provider.isExpressionClassBody():
             return ExpressionBuiltinLocalsRef(
-                locals_scope = provider.getFunctionLocalsScope(),
-                source_ref   = source_ref
+                locals_scope=provider.getFunctionLocalsScope(), source_ref=source_ref
             )
         elif python_version >= 300 or provider.isUnoptimized():
             assert provider.getFunctionLocalsScope(), provider
 
             return ExpressionBuiltinLocalsUpdated(
-                locals_scope = provider.getFunctionLocalsScope(),
-                source_ref   = source_ref
+                locals_scope=provider.getFunctionLocalsScope(), source_ref=source_ref
             )
         else:
             # TODO: Make this not true, there ought to be always a locals
@@ -445,6 +406,5 @@ def makeExpressionBuiltinLocals(provider, source_ref):
             assert not provider.getFunctionLocalsScope(), provider
 
             return ExpressionBuiltinLocalsCopy(
-                locals_scope = provider.getFunctionLocalsScope(),
-                source_ref   = source_ref
+                locals_scope=provider.getFunctionLocalsScope(), source_ref=source_ref
             )
