@@ -1,4 +1,4 @@
-#     Copyright 2017, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2019, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Part of "Nuitka", an optimizing Python compiler that is compatible and
 #     integrates with CPython, but also works on its own.
@@ -23,46 +23,39 @@ achieve more compact code, or predict results at compile time.
 There will be a method "computeExpressionSlice" to aid predicting them.
 """
 
-from nuitka.optimizations import BuiltinOptimization
 from nuitka.PythonVersions import python_version
+from nuitka.specs import BuiltinParameterSpecs
 
 from .ConstantRefNodes import ExpressionConstantNoneRef
-from .NodeBases import (
-    ChildrenHavingMixin,
+from .ExpressionBases import (
     ExpressionChildrenHavingBase,
-    ExpressionSpecBasedComputationMixin,
-    NodeBase,
-    StatementChildrenHavingBase
+    ExpressionSpecBasedComputationBase,
 )
+from .NodeBases import StatementChildrenHavingBase
 from .NodeMakingHelpers import (
     convertNoneConstantToNone,
     makeStatementExpressionOnlyReplacementNode,
-    makeStatementOnlyNodesFromExpressions
+    makeStatementOnlyNodesFromExpressions,
 )
 
 
 class StatementAssignmentSlice(StatementChildrenHavingBase):
     kind = "STATEMENT_ASSIGNMENT_SLICE"
 
-    named_children = (
-        "source",
-        "expression",
-        "lower",
-        "upper"
-    )
+    named_children = ("source", "expression", "lower", "upper")
 
     def __init__(self, expression, lower, upper, source, source_ref):
         assert python_version < 300
 
         StatementChildrenHavingBase.__init__(
             self,
-            values     = {
-                "source"     : source,
-                "expression" : expression,
-                "lower"      : lower,
-                "upper"      : upper
+            values={
+                "source": source,
+                "expression": expression,
+                "lower": lower,
+                "upper": upper,
             },
-            source_ref = source_ref
+            source_ref=source_ref,
         )
 
     getLookupSource = StatementChildrenHavingBase.childGetter("expression")
@@ -78,87 +71,82 @@ class StatementAssignmentSlice(StatementChildrenHavingBase):
         # away.
         if source.willRaiseException(BaseException):
             result = makeStatementExpressionOnlyReplacementNode(
-                expression = source,
-                node       = self
+                expression=source, node=self
             )
 
-            return result, "new_raise", """\
-Slice assignment raises exception in assigned value, removed assignment."""
+            return (
+                result,
+                "new_raise",
+                """\
+Slice assignment raises exception in assigned value, removed assignment.""",
+            )
 
         trace_collection.onExpression(self.getLookupSource())
         lookup_source = self.getLookupSource()
 
         if lookup_source.willRaiseException(BaseException):
             result = makeStatementOnlyNodesFromExpressions(
-                expressions = (
-                    source,
-                    lookup_source
-                )
+                expressions=(source, lookup_source)
             )
 
-            return result, "new_raise", """\
-Slice assignment raises exception in sliced value, removed assignment."""
+            return (
+                result,
+                "new_raise",
+                """\
+Slice assignment raises exception in sliced value, removed assignment.""",
+            )
 
-        trace_collection.onExpression(self.getLower(), allow_none = True)
+        trace_collection.onExpression(self.getLower(), allow_none=True)
         lower = self.getLower()
 
         if lower is not None and lower.willRaiseException(BaseException):
             result = makeStatementOnlyNodesFromExpressions(
-                expressions = (
-                    source,
-                    lookup_source,
-                    lower
-                )
+                expressions=(source, lookup_source, lower)
             )
 
-            return result, "new_raise", """\
+            return (
+                result,
+                "new_raise",
+                """\
 Slice assignment raises exception in lower slice boundary value, removed \
-assignment."""
+assignment.""",
+            )
 
-        trace_collection.onExpression(self.getUpper(), allow_none = True)
+        trace_collection.onExpression(self.getUpper(), allow_none=True)
         upper = self.getUpper()
 
         if upper is not None and upper.willRaiseException(BaseException):
             result = makeStatementOnlyNodesFromExpressions(
-                expressions = (
-                    source,
-                    lookup_source,
-                    lower,
-                    upper
-                )
+                expressions=(source, lookup_source, lower, upper)
             )
 
-            return result, "new_raise", """\
+            return (
+                result,
+                "new_raise",
+                """\
 Slice assignment raises exception in upper slice boundary value, removed \
-assignment."""
+assignment.""",
+            )
 
         return lookup_source.computeExpressionSetSlice(
-            set_node         = self,
-            lower            = lower,
-            upper            = upper,
-            value_node       = source,
-            trace_collection = trace_collection
+            set_node=self,
+            lower=lower,
+            upper=upper,
+            value_node=source,
+            trace_collection=trace_collection,
         )
 
 
 class StatementDelSlice(StatementChildrenHavingBase):
     kind = "STATEMENT_DEL_SLICE"
 
-    named_children = (
-        "expression",
-        "lower",
-        "upper"
-    )
+    named_children = ("expression", "lower", "upper")
 
     def __init__(self, expression, lower, upper, source_ref):
         StatementChildrenHavingBase.__init__(
             self,
-            values     = {
-                "expression" : expression,
-                "lower"      : lower,
-                "upper"      : upper
-            },
-            source_ref = source_ref
+            values={"expression": expression, "lower": lower, "upper": upper},
+            source_ref=source_ref,
         )
 
     getLookupSource = StatementChildrenHavingBase.childGetter("expression")
@@ -171,76 +159,65 @@ class StatementDelSlice(StatementChildrenHavingBase):
 
         if lookup_source.willRaiseException(BaseException):
             result = makeStatementExpressionOnlyReplacementNode(
-                expression = lookup_source,
-                node       = self
+                expression=lookup_source, node=self
             )
 
-            return result, "new_raise", """\
-Slice del raises exception in sliced value, removed del"""
+            return (
+                result,
+                "new_raise",
+                """\
+Slice del raises exception in sliced value, removed del""",
+            )
 
-
-        trace_collection.onExpression(self.getLower(), allow_none = True)
+        trace_collection.onExpression(self.getLower(), allow_none=True)
         lower = self.getLower()
 
         if lower is not None and lower.willRaiseException(BaseException):
             result = makeStatementOnlyNodesFromExpressions(
-                expressions = (
-                    lookup_source,
-                    lower
-                )
+                expressions=(lookup_source, lower)
             )
 
-            return result, "new_raise", """
-Slice del raises exception in lower slice boundary value, removed del"""
+            return (
+                result,
+                "new_raise",
+                """
+Slice del raises exception in lower slice boundary value, removed del""",
+            )
 
-        trace_collection.onExpression(self.getUpper(), allow_none = True)
+        trace_collection.onExpression(self.getUpper(), allow_none=True)
         upper = self.getUpper()
 
         if upper is not None and upper.willRaiseException(BaseException):
             result = makeStatementOnlyNodesFromExpressions(
-                expressions = (
-                    lookup_source,
-                    lower,
-                    upper
-                )
+                expressions=(lookup_source, lower, upper)
             )
 
-            return result, "new_raise", """
-Slice del raises exception in upper slice boundary value, removed del"""
+            return (
+                result,
+                "new_raise",
+                """
+Slice del raises exception in upper slice boundary value, removed del""",
+            )
 
         return lookup_source.computeExpressionDelSlice(
-            set_node         = self,
-            lower            = lower,
-            upper            = upper,
-            trace_collection = trace_collection
+            set_node=self, lower=lower, upper=upper, trace_collection=trace_collection
         )
 
 
 class ExpressionSliceLookup(ExpressionChildrenHavingBase):
     kind = "EXPRESSION_SLICE_LOOKUP"
 
-    named_children = (
-        "expression",
-        "lower",
-        "upper"
-    )
+    named_children = ("expression", "lower", "upper")
 
-    checkers   = {
-        "upper" : convertNoneConstantToNone,
-        "lower" : convertNoneConstantToNone
-    }
+    checkers = {"upper": convertNoneConstantToNone, "lower": convertNoneConstantToNone}
 
     def __init__(self, expression, lower, upper, source_ref):
         assert python_version < 300
 
         ExpressionChildrenHavingBase.__init__(
             self,
-            values     = {
-                "expression" : expression,
-                "upper"      : upper,
-                "lower"      : lower
-            },
-            source_ref = source_ref
+            values={"expression": expression, "upper": upper, "lower": lower},
+            source_ref=source_ref,
         )
 
     getLookupSource = ExpressionChildrenHavingBase.childGetter("expression")
@@ -255,10 +232,10 @@ class ExpressionSliceLookup(ExpressionChildrenHavingBase):
         lookup_source = self.getLookupSource()
 
         return lookup_source.computeExpressionSlice(
-            lookup_node      = self,
-            lower            = self.getLower(),
-            upper            = self.getUpper(),
-            trace_collection = trace_collection
+            lookup_node=self,
+            lower=self.getLower(),
+            upper=self.getUpper(),
+            trace_collection=trace_collection,
         )
 
     def isKnownToBeIterable(self, count):
@@ -266,44 +243,25 @@ class ExpressionSliceLookup(ExpressionChildrenHavingBase):
         return None
 
 
-class ExpressionBuiltinSlice(ChildrenHavingMixin, NodeBase,
-                             ExpressionSpecBasedComputationMixin):
+class ExpressionBuiltinSlice(ExpressionSpecBasedComputationBase):
     kind = "EXPRESSION_BUILTIN_SLICE"
 
-    named_children = (
-        "start",
-        "stop",
-        "step"
-    )
+    named_children = ("start", "stop", "step")
 
-    builtin_spec = BuiltinOptimization.builtin_slice_spec
+    builtin_spec = BuiltinParameterSpecs.builtin_slice_spec
 
     def __init__(self, start, stop, step, source_ref):
-        NodeBase.__init__(
-            self,
-            source_ref = source_ref
-        )
-
         if start is None:
-            start = ExpressionConstantNoneRef(
-                source_ref = source_ref
-            )
+            start = ExpressionConstantNoneRef(source_ref=source_ref)
         if stop is None:
-            stop = ExpressionConstantNoneRef(
-                source_ref = source_ref
-            )
+            stop = ExpressionConstantNoneRef(source_ref=source_ref)
         if step is None:
-            step = ExpressionConstantNoneRef(
-                source_ref = source_ref
-            )
+            step = ExpressionConstantNoneRef(source_ref=source_ref)
 
-        ChildrenHavingMixin.__init__(
+        ExpressionSpecBasedComputationBase.__init__(
             self,
-            values = {
-                "start" : start,
-                "stop"  : stop,
-                "step"  : step
-            }
+            values={"start": start, "stop": stop, "step": step},
+            source_ref=source_ref,
         )
 
     def computeExpression(self, trace_collection):
@@ -311,22 +269,19 @@ class ExpressionBuiltinSlice(ChildrenHavingMixin, NodeBase,
         stop = self.getStop()
         step = self.getStep()
 
-        args = (
-            start,
-            stop,
-            step
-        )
+        args = (start, stop, step)
 
         return self.computeBuiltinSpec(
-            trace_collection = trace_collection,
-            given_values     = args
+            trace_collection=trace_collection, given_values=args
         )
 
     def mayRaiseException(self, exception_type):
-        return self.getStart().mayRaiseException(exception_type) or \
-               self.getStop().mayRaiseException(exception_type) or \
-               self.getStep().mayRaiseException(exception_type)
+        return (
+            self.getStart().mayRaiseException(exception_type)
+            or self.getStop().mayRaiseException(exception_type)
+            or self.getStep().mayRaiseException(exception_type)
+        )
 
-    getStart = ChildrenHavingMixin.childGetter("start")
-    getStop = ChildrenHavingMixin.childGetter("stop")
-    getStep = ChildrenHavingMixin.childGetter("step")
+    getStart = ExpressionSpecBasedComputationBase.childGetter("start")
+    getStop = ExpressionSpecBasedComputationBase.childGetter("stop")
+    getStep = ExpressionSpecBasedComputationBase.childGetter("step")
