@@ -42,6 +42,7 @@ class NuitkaPluginMultiprocessingWorkarounds(NuitkaPluginBase):
     """
 
     plugin_name = "multiprocessing"
+    plugin_desc = "Required by Python's multiprocessing module"
 
     def __init__(self):
         self.multiprocessing_added = False
@@ -52,9 +53,12 @@ class NuitkaPluginMultiprocessingWorkarounds(NuitkaPluginBase):
 
         if full_name == "multiprocessing":
             code = """\
-import sys
+import sys, os
 sys.frozen = 1
-sys.executable = sys.argv[0]
+if not os.path.exists(sys.argv[0]) and not sys.argv[0].endswith(".exe"):
+    sys.executable = sys.argv[0] + ".exe"
+else:
+    sys.executable = sys.argv[0]
 """
             return (
                 code,
