@@ -1,4 +1,4 @@
-#     Copyright 2018, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2019, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Part of "Nuitka", an optimizing Python compiler that is compatible and
 #     integrates with CPython, but also works on its own.
@@ -29,13 +29,14 @@ from nuitka.SourceCodeReferences import fromFilename
 
 internal_source_ref = fromFilename("internal").atInternal()
 
+
 def once_decorator(func):
     """ Cache result of a function call without arguments.
 
     Used for all internal function accesses to become a singleton.
 
     Note: This doesn't much specific anymore, but we are not having
-    this often enough to warrent re-use or generalization.
+    this often enough to warrant re-use or generalization.
 
     """
 
@@ -61,11 +62,11 @@ def getInternalModule():
 
 def makeInternalHelperFunctionBody(name, parameters):
     return ExpressionFunctionBody(
-        provider    = getInternalModule(),
-        name        = name,
-        code_object = None,
-        doc         = None,
-        parameters  = parameters,
-        flags       = set(),
-        source_ref  = internal_source_ref
+        provider=getInternalModule(),
+        name=name,
+        code_object=None,
+        doc=None,
+        parameters=parameters,
+        flags=set(),
+        source_ref=internal_source_ref,
     )
